"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
const _react = /*#__PURE__*/ _interop_require_wildcard(require("react"));
const _fieldeditortestutils = require("@contentful/field-editor-test-utils");
require("@testing-library/jest-dom/extend-expect");
const _react1 = require("@testing-library/react");
const _DropdownEditor = require("./DropdownEditor");
function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function(nodeInterop) {
        return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
}
function _interop_require_wildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
        return obj;
    }
    if (obj === null || typeof obj !== "object" && typeof obj !== "function") {
        return {
            default: obj
        };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
        return cache.get(obj);
    }
    var newObj = {
        __proto__: null
    };
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for(var key in obj){
        if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
            if (desc && (desc.get || desc.set)) {
                Object.defineProperty(newObj, key, desc);
            } else {
                newObj[key] = obj[key];
            }
        }
    }
    newObj.default = obj;
    if (cache) {
        cache.set(obj, newObj);
    }
    return newObj;
}
(0, _react1.configure)({
    testIdAttribute: 'data-test-id'
});
describe('DropdownEditor', ()=>{
    afterEach(_react1.cleanup);
    it('renders a warning if no options are present', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((mock)=>{
            return {
                ...mock,
                validations: []
            };
        });
        const { getByTestId, queryByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        expect(getByTestId('predefined-values-warning')).toBeInTheDocument();
        expect(queryByTestId('dropdown-editor')).not.toBeInTheDocument();
    });
    it('renders option tags for predefined values', ()=>{
        const predefined = [
            'banana',
            'orange',
            'strawberry'
        ];
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((mock)=>{
            return {
                ...mock,
                validations: [
                    {
                        in: predefined
                    }
                ]
            };
        });
        const { container, getByText } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        expect(container.querySelectorAll('option')).toHaveLength(4);
        expect(getByText('Choose a value')).toHaveValue('');
        predefined.forEach((item)=>{
            expect(getByText(item)).toHaveValue(item);
        });
    });
    it('calls setValue if user select on default option', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'setValue');
            jest.spyOn(field, 'removeValue');
            return {
                ...field,
                validations: [
                    {
                        in: [
                            'initial'
                        ]
                    }
                ]
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        const changeDropdownValue = (value)=>_react1.fireEvent.change(getByTestId('dropdown-editor'), {
                target: {
                    value
                }
            });
        expect(getByTestId('dropdown-editor')).toHaveValue('');
        changeDropdownValue('initial');
        expect(field.setValue).toHaveBeenCalledWith('initial');
        expect(field.setValue).toHaveBeenCalledTimes(1);
    });
    it('calls removeValue if user selects default option', ()=>{
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'removeValue');
            return {
                ...field,
                getValue: ()=>'initial',
                validations: [
                    {
                        in: [
                            'initial'
                        ]
                    }
                ]
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        const changeDropdownValue = (value)=>_react1.fireEvent.change(getByTestId('dropdown-editor'), {
                target: {
                    value
                }
            });
        expect(getByTestId('dropdown-editor')).toHaveValue('initial');
        changeDropdownValue('');
        expect(field.removeValue).toHaveBeenCalledTimes(1);
    });
    it('calls #setValue with number for Number fields', function() {
        const predefined = [
            1,
            '2.71',
            3
        ];
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'setValue');
            jest.spyOn(field, 'removeValue');
            return {
                ...field,
                type: 'Number',
                validations: [
                    {
                        in: predefined
                    }
                ]
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        const $editorInput = getByTestId('dropdown-editor');
        const changeDropdownValue = (value)=>_react1.fireEvent.change($editorInput, {
                target: {
                    value
                }
            });
        expect($editorInput).toHaveValue('');
        changeDropdownValue('2.71');
        expect($editorInput).toHaveValue('2.71');
        expect(field.setValue).toHaveBeenCalledWith(2.71);
        expect(field.setValue).toHaveBeenCalledTimes(1);
    });
    it('calls #setValue with number for Integer fields', function() {
        const predefined = [
            0,
            1,
            '2',
            3
        ];
        const [field] = (0, _fieldeditortestutils.createFakeFieldAPI)((field)=>{
            jest.spyOn(field, 'setValue');
            jest.spyOn(field, 'removeValue');
            return {
                ...field,
                type: 'Number',
                validations: [
                    {
                        in: predefined
                    }
                ]
            };
        });
        const { getByTestId } = (0, _react1.render)(/*#__PURE__*/ _react.createElement(_DropdownEditor.DropdownEditor, {
            field: field,
            locales: (0, _fieldeditortestutils.createFakeLocalesAPI)(),
            isInitiallyDisabled: false
        }));
        const $editorInput = getByTestId('dropdown-editor');
        const changeDropdownValue = (value)=>_react1.fireEvent.change($editorInput, {
                target: {
                    value
                }
            });
        expect($editorInput).toHaveValue('');
        changeDropdownValue('1');
        expect(field.setValue).toHaveBeenCalledWith(1);
        expect(field.setValue).toHaveBeenCalledTimes(1);
        expect($editorInput).toHaveValue('1');
        changeDropdownValue('0');
        expect(field.setValue).toHaveBeenCalledWith(0);
        expect(field.setValue).toHaveBeenCalledTimes(2);
        expect($editorInput).toHaveValue('0');
    });
});
