import * as React from 'react';
import { Select } from '@contentful/f36-components';
import { FieldConnector, PredefinedValuesError } from '@contentful/field-editor-shared';
import { getOptions, parseValue } from './dropdownUtils';
import * as styles from './styles';
export function DropdownEditor(props) {
    const { field, locales, id } = props;
    const options = getOptions(field);
    const misconfigured = options.length === 0;
    if (misconfigured) {
        return /*#__PURE__*/ React.createElement(PredefinedValuesError, null);
    }
    const direction = locales.direction[field.locale] || 'ltr';
    return /*#__PURE__*/ React.createElement(FieldConnector, {
        debounce: 0,
        field: field,
        isInitiallyDisabled: props.isInitiallyDisabled
    }, ({ value, errors, disabled, setValue })=>/*#__PURE__*/ React.createElement(Select, {
            testId: "dropdown-editor",
            id: id,
            isInvalid: errors.length > 0,
            isDisabled: disabled,
            className: direction === 'rtl' ? styles.rightToLeft : '',
            isRequired: field.required,
            value: value === undefined ? '' : String(value),
            onChange: (e)=>{
                const value = e.target.value;
                setValue(parseValue(value, field.type));
            }
        }, /*#__PURE__*/ React.createElement(Select.Option, {
            value: ""
        }, "Choose a value"), options.map((option)=>/*#__PURE__*/ React.createElement(Select.Option, {
                key: option.value,
                value: String(option.value)
            }, option.label))));
}
DropdownEditor.defaultProps = {
    isInitiallyDisabled: true
};
